# Generated by roxygen2: do not edit by hand

S3method(print,nl_compare)
S3method(print,nl_fit)
S3method(print,nl_r2)
S3method(print,summary_nl_fit)
S3method(summary,nl_fit)
export(nl_compare)
export(nl_derivatives)
export(nl_fit)
export(nl_het)
export(nl_icc)
export(nl_knots)
export(nl_plot)
export(nl_predict)
export(nl_r2)
export(nl_summary)
export(nl_turning_points)
importFrom(rlang,"%||%")
importFrom(rlang,.data)
importFrom(splines,bs)
importFrom(splines,ns)
